        function getT(rr,cc){
       if(rr==4 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260504 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==4 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260504 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>13</strong> miembros: 22 <strong>control</strong><br>0,6,10,12,13,14,17,18,19,20,21,23,24,25,30,35,38,41,42,43,44,47';}
       if(rr==4 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260504 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>28</strong> miembros: 15 <br>1,3,7,15,26,27,28,33,34,36,37,40,45,49,50';}
       if(rr==4 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260504 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>3</strong> representante: <strong>2</strong> miembros: 14 <br>2,4,5,8,9,11,16,22,29,31,32,39,46,48';}
       if(rr==23 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260504 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==23 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260504 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>13</strong> miembros: 22 <strong>control</strong><br>0,6,10,12,13,14,17,18,19,20,21,23,24,25,30,35,38,41,42,43,44,47';}
       if(rr==23 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260504 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>28</strong> miembros: 15 <br>1,3,7,15,26,27,28,33,34,36,37,40,45,49,50';}
       if(rr==23 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260504 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>3</strong> representante: <strong>2</strong> miembros: 14 <br>2,4,5,8,9,11,16,22,29,31,32,39,46,48';}
       if(rr==25 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260504 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==25 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260504 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>13</strong> miembros: 22 <strong>control</strong><br>0,6,10,12,13,14,17,18,19,20,21,23,24,25,30,35,38,41,42,43,44,47';}
       if(rr==25 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260504 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>28</strong> miembros: 15 <br>1,3,7,15,26,27,28,33,34,36,37,40,45,49,50';}
       if(rr==25 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260504 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>3</strong> representante: <strong>2</strong> miembros: 14 <br>2,4,5,8,9,11,16,22,29,31,32,39,46,48';}
       if(rr==26 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260504 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==26 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260504 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>13</strong> miembros: 22 <strong>control</strong><br>0,6,10,12,13,14,17,18,19,20,21,23,24,25,30,35,38,41,42,43,44,47';}
       if(rr==26 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260504 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>28</strong> miembros: 15 <br>1,3,7,15,26,27,28,33,34,36,37,40,45,49,50';}
       if(rr==26 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260504 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>3</strong> representante: <strong>2</strong> miembros: 14 <br>2,4,5,8,9,11,16,22,29,31,32,39,46,48';}
       if(rr==27 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260504 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==27 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260504 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>13</strong> miembros: 22 <strong>control</strong><br>0,6,10,12,13,14,17,18,19,20,21,23,24,25,30,35,38,41,42,43,44,47';}
       if(rr==27 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260504 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>28</strong> miembros: 15 <br>1,3,7,15,26,27,28,33,34,36,37,40,45,49,50';}
       if(rr==27 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260504 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>3</strong> representante: <strong>2</strong> miembros: 14 <br>2,4,5,8,9,11,16,22,29,31,32,39,46,48';}
       if(rr==28 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260504 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==28 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260504 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>13</strong> miembros: 22 <strong>control</strong><br>0,6,10,12,13,14,17,18,19,20,21,23,24,25,30,35,38,41,42,43,44,47';}
       if(rr==28 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260504 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>28</strong> miembros: 15 <br>1,3,7,15,26,27,28,33,34,36,37,40,45,49,50';}
       if(rr==28 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260504 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>3</strong> representante: <strong>2</strong> miembros: 14 <br>2,4,5,8,9,11,16,22,29,31,32,39,46,48';}
}
